import { world, Player, Entity } from '@minecraft/server';
import { ActionFormData, MessageFormData, ModalFormData } from '@minecraft/server-ui';
import './VillagerGUI.js';
import { open_villagerGUI, open_wandering_traderGUI } from "./VillagerGUI.js";

export function getRandomInt(min, max) {
  	return Math.floor(Math.random() * (max - min)) + min;
}

export function getScore(target, objectiveId, rNull = false) {
  try {
    return world.scoreboard
      .getObjective(objectiveId)
      .getScore(target.scoreboard);
  } catch (error) {
    return rNull ? null : 0;
  }
}

world.events.tick.subscribe(() => {
	for (const player of world.getPlayers()) {
		let entity = player.getEntitiesFromViewVector();
		let player_relationship = "relationship_" + player.nameTag;
		let relationship = getScore(entity[0], player_relationship);
		let favorite_food = getScore(entity[0], "favorite_food");
		if (player.hasTag("villager_gui")) {
			player.runCommandAsync("tag @s remove villager_gui");
			open_villagerGUI(player);
		}
		if (player.hasTag("wandering_trader_gui")) {
			player.runCommandAsync("tag @s remove wandering_trader_gui");
			open_wandering_traderGUI(player);
		}
		if (player.hasTag("gift_apple")) {
			player.runCommandAsync("tag @s remove gift_apple");
			if (favorite_food != 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_appleEnchanted")) {
			player.runCommandAsync("tag @s remove gift_appleEnchanted");
			if (favorite_food != 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 5`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 6`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_beef")) {
			player.runCommandAsync("tag @s remove gift_beef");
			if (favorite_food != 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_beetroot")) {
			player.runCommandAsync("tag @s remove gift_beetroot");
			if (favorite_food != 2) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 2) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_beetroot_soup")) {
			player.runCommandAsync("tag @s remove gift_beetroot_soup");
			if (favorite_food != 5) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 5) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_bread")) {
			player.runCommandAsync("tag @s remove gift_bread");
			if (favorite_food != 6) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 6) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_cake")) {
			player.runCommandAsync("tag @s remove gift_cake");
			if (favorite_food != 4) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 4) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 4`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_carrot")) {
			player.runCommandAsync("tag @s remove gift_carrot");
			if (favorite_food != 2) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 2) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_chicken")) {
			player.runCommandAsync("tag @s remove gift_chicken");
			if (favorite_food != 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_chorus_fruit")) {
			player.runCommandAsync("tag @s remove gift_appleEnchanted");
			if (favorite_food != 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_cookie")) {
			player.runCommandAsync("tag @s remove gift_cookie");
			if (favorite_food != 4) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 4) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_fish")) {
			player.runCommandAsync("tag @s remove gift_fish");
			if (favorite_food != 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_flower")) {
			player.runCommandAsync("tag @s remove gift_flower");
			if (entity[0].hasTag("energetic")) {
				entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.flower"}]}`)
			}
			if (entity[0].hasTag("flirty")) {
				entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.flower"}]}`)
			}
			if (entity[0].hasTag("rude")) {
				entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.flower"}]}`)
			}
			if (entity[0].hasTag("shy")) {
				entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.flower"}]}`)
			}
			entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
			entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
		}
		if (player.hasTag("gift_glow_berries")) {
			player.runCommandAsync("tag @s remove gift_glow_berries");
			if (favorite_food != 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_golden_apple")) {
			player.runCommandAsync("tag @s remove gift_golden_apple");
			if (favorite_food != 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 4`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_golden_carrot")) {
			player.runCommandAsync("tag @s remove gift_golden_carrot");
			if (favorite_food != 2) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 2) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_kelp")) {
			player.runCommandAsync("tag @s remove gift_kelp");
			if (favorite_food != 7) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 7) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_melon")) {
			player.runCommandAsync("tag @s remove gift_melon");
			if (favorite_food != 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_mushroom_stew")) {
			player.runCommandAsync("tag @s remove gift_mushroom_stew");
			if (favorite_food != 5) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 5) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_mutton")) {
			player.runCommandAsync("tag @s remove gift_mutton");
			if (favorite_food != 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_pork")) {
			player.runCommandAsync("tag @s remove gift_pork");
			if (favorite_food != 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_potato")) {
			player.runCommandAsync("tag @s remove gift_potato");
			if (favorite_food != 2) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 2) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_pumpkin_pie")) {
			player.runCommandAsync("tag @s remove gift_pumpkin_pie");
			if (favorite_food != 4) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 4) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 4`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_rabbit")) {
			player.runCommandAsync("tag @s remove gift_rabbit");
			if (favorite_food != 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_rabbit_stew")) {
			player.runCommandAsync("tag @s remove gift_rabbit_stew");
			if (favorite_food != 5) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 5) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_salmon")) {
			player.runCommandAsync("tag @s remove gift_salmon");
			if (favorite_food != 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 3) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 3`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_sweet_berries")) {
			player.runCommandAsync("tag @s remove gift_sweet_berries");
			if (favorite_food != 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.like"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.like"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 1`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
			if (favorite_food == 1) {
				if (entity[0].hasTag("energetic")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("flirty")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("rude")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.love"}]}`)
				}
				if (entity[0].hasTag("shy")) {
					entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.love"}]}`)
				}
				entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} 2`);
				entity[0].runCommandAsync(`particle minecraft:heart_particle ~ ~2 ~`);
			}
		}
		if (player.hasTag("gift_wither_rose")) {
			player.runCommandAsync("tag @s remove gift_wither_rose");
			if (entity[0].hasTag("energetic")) {
				entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"energetic_villager.gift.wither_rose"}]}`)
			}
			if (entity[0].hasTag("flirty")) {
				entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"flirty_villager.gift.wither_rose"}]}`)
			}
			if (entity[0].hasTag("rude")) {
				entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"rude_villager.gift.wither_rose"}]}`)
			}
			if (entity[0].hasTag("shy")) {
				entity[0].runCommandAsync(`tellraw @p {"rawtext":[{"translate":"shy_villager.gift.wither_rose"}]}`)
			}
			entity[0].runCommandAsync(`scoreboard players add @s ${player_relationship} -2`);
			entity[0].runCommandAsync(`particle minecraft:villager_angry ~ ~2 ~`);
		}
	}
});

function villagerSetup() {
	const entities = Array.from(world.getDimension("overworld").getEntities())
	for(const entity of entities) {
		if (!entity.hasTag("setup_complete")) {
			var personality = getRandomInt(0, 4);
	        if (entity.typeId == 'bca:villager_female') {
				if (personality == 0) {
    	        	entity.addTag("energetic");
				}
				if (personality == 1) {
    	        	entity.addTag("flirty");
				}
				if (personality == 2) {
    	        	entity.addTag("rude");
				}
				if (personality == 3) {
    	        	entity.addTag("shy");
				}
     	   }
			if (entity.typeId == 'bca:villager_male') {
				if (personality == 0) {
    	        	entity.addTag("energetic");
				}
				if (personality == 1) {
    	        	entity.addTag("flirty");
				}
				if (personality == 2) {
    	        	entity.addTag("rude");
				}
				if (personality == 3) {
    	        	entity.addTag("shy");
				}
     	   }
     	   entity.addTag("setup_complete");
        }
    }
};

world.events.entityCreate.subscribe(villagerSetup)